@@ -8,17 +8,18 @@ use IO::All;
 
 my $new_ver = shift(@ARGV);
 
-my $tree = File::Find::Object->new({}, 'lib/Games/Solitaire/');
+my $tree = File::Find::Object->new( {}, 'lib/Games/Solitaire/' );
 
-while (my $r = $tree->next()) {
-    if ($r =~ m{/\.svn\z})
+while ( my $r = $tree->next() )
+{
+    if ( $r =~ m{/\.svn\z} )
     {
         $tree->prune();
     }
-    elsif ($r =~ m{\.pm\z})
+    elsif ( $r =~ m{\.pm\z} )
     {
         my @lines = io->file($r)->getlines();
-        LINES_LOOP:
+    LINES_LOOP:
         foreach (@lines)
         {
             if (s#(\$VERSION = ')\d+\.\d+(')#$1 . $new_ver . $2#e)
@@ -26,8 +27,6 @@ while (my $r = $tree->next()) {
                 last LINES_LOOP;
             }
         }
-        io->file($r)->print(
-            @lines
-        );
+        io->file($r)->print(@lines);
     }
 }
